"use client";

import { StorageIcon } from "@/app/components/icon/storage-icon";
import { Stat } from "@/app/components/stat";
import { ReactElement } from "react";
import useWebSocket from "react-use-websocket";
import { PersonIcon } from "./icon/person-icon";
import { TrendingUpIcon } from "./icon/trending-up-icon";
import { Tooltip, TooltipContent, TooltipTrigger } from "./ui/tooltip";

type Stat = {
  id: string;
  displayName: string;
  tooltip: string;
  icon: ReactElement;
};

const stats: Stat[] = [
  {
    id: "totalRequests",
    displayName: "Total Requests",
    tooltip: "The total amount of requests to the API",
    icon: <TrendingUpIcon />,
  },
  {
    id: "totalPlayerLookups",
    displayName: "Player Lookups",
    tooltip: "The total amount of player lookups",
    icon: <PersonIcon />,
  },
  {
    id: "totalServerLookups",
    displayName: "Server Lookups",
    tooltip: "The total amount of server lookups",
    icon: <StorageIcon />,
  },
];

export function Stats(): ReactElement {
  const { lastMessage } = useWebSocket("wss://api.mcutils.xyz/websocket/metrics");
  const metrics = lastMessage !== null ? JSON.parse(lastMessage.data).metrics : undefined;

  return (
    <div className="flex gap-4 flex-wrap justify-center">
      {stats.map((stat, index) => {
        const value = metrics ? metrics[stat.id] : "???";

        return (
          <Tooltip key={index}>
            <TooltipTrigger className="cursor-default">
              <Stat title={stat.displayName} value={value} icon={stat.icon} />
            </TooltipTrigger>
            <TooltipContent>
              <p>{stat.tooltip}</p>
            </TooltipContent>
          </Tooltip>
        );
      })}
    </div>
  );
}
