import { Fonts } from "@/common/fonts";
import { Metadata, Viewport } from "next";

import "./globals.css";

import Script from "next/script";
import Config from "../../config.json";
import Container from "./components/container";
import ThemeProvider from "./components/theme-provider";
import { Toaster } from "./components/ui/toaster";
import { TooltipProvider } from "./components/ui/tooltip";

export const viewport: Viewport = {
  themeColor: "#3498DB",
};

export const metadata: Metadata = {
  metadataBase: new URL(Config.siteUrl),
  title: {
    template: Config.siteName + " - %s",
    default: Config.siteName,
  },
  description: Config.siteDescription,
  keywords: "Minecraft, APIs, wrapper, utility, development",
  openGraph: {
    title: Config.siteName,
    description: Config.siteDescription,
    url: Config.siteUrl,
    locale: "en_US",
    type: "website",
    images: [
      {
        url: "https://git.fascinated.cc/MinecraftUtilities/Assets/raw/branch/master/logo.png",
      },
    ],
  },
  twitter: {
    card: "summary",
  },
};

export default function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode;
}>): JSX.Element {
  return (
    <>
      <Script defer data-domain="mcutils.xyz" src="https://analytics.fascinated.cc/js/script.js" />
      <html className={Fonts.inter.className} lang="en" suppressHydrationWarning>
        <head />
        <body>
          <ThemeProvider attribute="class" defaultTheme="dark" enableSystem>
            <TooltipProvider>
              <Toaster />
              <Container>{children}</Container>
            </TooltipProvider>
          </ThemeProvider>
        </body>
      </html>
    </>
  );
}
